/*
 *  Eukleides version 1.5.4
 *  Copyright (c) Christian Obrecht 2004-2010
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

void create_point_cartesian(_param p);

void create_point_polar(_param p);

void create_point_on_segment(_param p);

void create_point_on_line(_param p);

void create_point_with_abscissa(_param p);

void create_point_with_ordinate(_param p);

void create_point_on_circle(_param p);

void create_point_on_conic(_param p);

void create_midpoint(_param p);

void create_isobarycenter(_param p);

void create_barycenter(_param p);

void create_orthocenter(_param p);

void translate_point(_param p);

void reflect_point(_param p);

void symetric_point(_param p);

void rotate_point(_param p);

void homothetic_point(_param p);

void point_abscissa(_param p);

void point_ordinate(_param p);

void points_distance(_param p);
